@@ -21,25 +21,30 @@ from linux_thermaltake_rgb.devices import ThermaltakeRGBDevice
 
 
 class ThermaltakePR22D5Res(ThermaltakeRGBDevice):
+    model = 'Pacific PR22-D5 Plus'
     num_leds = 12
     index_per_led = 3
 
 
 class ThermaltakeW4PlusWB(ThermaltakeRGBDevice):
+    model = 'Pacific W4 Plus CPU Waterblock'
     num_leds = 12
     index_per_led = 3
 
 
 class ThermaltakeVGTX1080PlusWB(ThermaltakeRGBDevice):
+    model = 'Pacific V-GTX 1080Ti Plus GPU Waterblock'
     num_leds = 12
     index_per_led = 3
 
 
 class ThermaltakeRadPlusLED(ThermaltakeRGBDevice):
+    model = 'Pacific Rad Plus LED Panel'
     num_leds = 12
     index_per_led = 3
 
 
 class ThermaltakeLumiPlusLED(ThermaltakeRGBDevice):
+    model = 'Lumi Plus LED Strip'
     num_leds = 12
     index_per_led = 3
